Welcome to ClientVPS Mirrors

Help for package printr
Type: Package
Title: Automatically Print R Objects to Appropriate Formats According to the 'knitr' Output Format
Version: 0.3
Description: Extends the S3 generic function knit_print() in 'knitr' to automatically print some objects using an appropriate format such as Markdown or LaTeX. For example, data frames are automatically printed as tables, and the help() pages can also be rendered in 'knitr' documents.
Imports: knitr (≥ 1.31)
Suggests: tools, rmarkdown
License: GPL-2 | GPL-3 [expanded from: GPL]
URL: https://yihui.org/printr/
BugReports: https://github.com/yihui/printr/issues
VignetteBuilder: knitr
RoxygenNote: 7.2.3
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2023-03-08 19:27:23 UTC; yihui
Author: Yihui Xie ORCID iD [aut, cre]
Maintainer: Yihui Xie <xie@yihui.name>
Repository: CRAN
Date/Publication: 2023-03-08 19:40:03 UTC

Print R objects in knitr documents nicely

Description

The main documentation of this package is the package vignette ‘printr-intro.html’. Please check out vignette('printr', package = 'printr').

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.